From 787282ad72ac27b0e779617bcdea4dfb36401759 Mon Sep 17 00:00:00 2001
From: Fei Xu <xufei30@huawei.com>
Date: Mon, 23 Nov 2020 11:10:16 +0800
Subject: [PATCH 3/3] device_model:remove the trait of DeviceOps in mmio/mod.rs
 and use the trait of DeviceOps in lib.rs

Signed-off-by: Fei Xu <xufei30@huawei.com>
---
 device_model/src/legacy/pl031.rs     | 7 +++++--
 device_model/src/legacy/serial.rs    | 7 +++++--
 device_model/src/mmio/mod.rs         | 7 +------
 device_model/src/mmio/virtio_mmio.rs | 7 +++++--
 4 files changed, 16 insertions(+), 12 deletions(-)

diff --git a/device_model/src/legacy/pl031.rs b/device_model/src/legacy/pl031.rs
index 623048d..0413c44 100644
--- a/device_model/src/legacy/pl031.rs
+++ b/device_model/src/legacy/pl031.rs
@@ -17,8 +17,11 @@ use byteorder::{ByteOrder, LittleEndian};
 use kvm_ioctls::VmFd;
 use vmm_sys_util::eventfd::EventFd;
 
-use super::super::mmio::errors::{Result, ResultExt};
-use super::super::mmio::{DeviceOps, DeviceResource, DeviceType, MmioDeviceOps};
+use super::super::mmio::{
+    errors::{Result, ResultExt},
+    DeviceResource, DeviceType, MmioDeviceOps,
+};
+use super::super::DeviceOps;
 
 /// Registers for pl032 from ARM PrimeCell Real Time Clock Technical Reference Manual.
 /// Data Register.
diff --git a/device_model/src/legacy/serial.rs b/device_model/src/legacy/serial.rs
index ba34a00..f1344a3 100644
--- a/device_model/src/legacy/serial.rs
+++ b/device_model/src/legacy/serial.rs
@@ -20,8 +20,11 @@ use kvm_ioctls::VmFd;
 use util::epoll_context::{EventNotifier, EventNotifierHelper, NotifierOperation};
 use vmm_sys_util::{epoll::EventSet, eventfd::EventFd, terminal::Terminal};
 
-use super::super::mmio::errors::{Result, ResultExt};
-use super::super::mmio::{DeviceOps, DeviceResource, DeviceType, MmioDeviceOps};
+use super::super::mmio::{
+    errors::{Result, ResultExt},
+    DeviceResource, DeviceType, MmioDeviceOps,
+};
+use super::super::DeviceOps;
 
 const UART_IER_RDI: u8 = 0x01;
 const UART_IER_THRI: u8 = 0x02;
diff --git a/device_model/src/mmio/mod.rs b/device_model/src/mmio/mod.rs
index cfb4d9b..d2f6295 100644
--- a/device_model/src/mmio/mod.rs
+++ b/device_model/src/mmio/mod.rs
@@ -33,6 +33,7 @@ mod virtio_mmio;
 
 pub use self::bus::Bus;
 pub use self::virtio_mmio::VirtioMmioDevice;
+use super::DeviceOps;
 
 use address_space::{AddressSpace, GuestAddress, Region, RegionIoEventFd, RegionOps};
 use error_chain::bail;
@@ -202,9 +203,3 @@ pub trait MmioDeviceOps: Send + DeviceOps {
         Vec::new()
     }
 }
-
-pub trait DeviceOps: Send {
-    fn read(&mut self, data: &mut [u8], base: GuestAddress, offset: u64) -> bool;
-
-    fn write(&mut self, data: &[u8], base: GuestAddress, offset: u64) -> bool;
-}
diff --git a/device_model/src/mmio/virtio_mmio.rs b/device_model/src/mmio/virtio_mmio.rs
index f61217a..8de2ba1 100644
--- a/device_model/src/mmio/virtio_mmio.rs
+++ b/device_model/src/mmio/virtio_mmio.rs
@@ -25,8 +25,11 @@ use super::super::virtio::{
     VIRTIO_TYPE_NET,
 };
 
-use super::errors::{ErrorKind, Result, ResultExt};
-use super::{DeviceOps, DeviceResource, DeviceType, MmioDeviceOps};
+use super::super::DeviceOps;
+use super::{
+    errors::{ErrorKind, Result, ResultExt},
+    DeviceResource, DeviceType, MmioDeviceOps,
+};
 
 /// Registers of virtio-mmio device refer to Virtio Spec.
 /// Magic value - Read Only.
-- 
2.27.0

